pub struct ArgSpec { /* private fields */ }Implementations
Sourceimpl ArgSpec
impl ArgSpec
pub fn new( req: Vec<RcStr>, def: Vec<(RcStr, ConstVal)>, var: Option<RcStr>, key: Option<RcStr>, ) -> ArgSpec
pub fn builder() -> ArgSpecBuilder
pub fn empty() -> ArgSpec
pub fn nparams(&self) -> usize
pub fn params(&self) -> Vec<RcStr>
pub fn apply( &self, flatten_varargs: bool, args: Vec<Value>, kwargs: Option<HashMap<RcStr, Value>>, ) -> Result<(Vec<Value>, Option<HashMap<RcStr, Value>>), Error>
Sourcepub fn apply_and_append_kwmap(
&self,
args: Vec<Value>,
kwargs: Option<HashMap<RcStr, Value>>,
) -> Result<Vec<Value>, Error>
pub fn apply_and_append_kwmap( &self, args: Vec<Value>, kwargs: Option<HashMap<RcStr, Value>>, ) -> Result<Vec<Value>, Error>
Like apply, but the kwargs map is converted to a Value and added to args if a kwargs parameter was specified
pub fn to_value(&self) -> Value